<?php

use EventPortal\Contracts\Event as EventContract;
use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Email\Composers\EmailSendComposer;
use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\UpdateModel;
use EventPortal\Enums\InertiaMethod;

Form::make('email.show')
    ->addFields(function () {
        return [
            Section::make('Details')->fields([
                Display::make('Subject'),
                Display::make('Sender email')
                    ->name('sender_address'),
                Display::make('Reply-to email')
                    ->name('reply_to_address'),
            ]),
        ];
    })
    ->addActions(function (EventEmail $email, EventContract $event) {
        $composer = new EmailSendComposer($event, $email);
        $composer->compose();

        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.email.index', [
                    'event' => $email->event->id,
                ]),
            Button::make('Edit Email')
                ->method(InertiaMethod::VISIT())
                ->route('admin.email.edit', [
                    'event' => $email->event->id,
                    'email' => $email->id,
                ]),
            Button::make('Send Email')
                ->modal([
                    'type' => 'confirm',
                    'content' => $composer->content,
                    'actions' => $composer->buttons,
                ]),
        ];
    });

Form::make('email.edit')
    ->addHandler(new UpdateModel)
    ->addFields(function () {
        return [
            Section::make('Details')->fields([
                Display::make('Type'),
                Text::make('Subject')
                    ->placeholder('You\'re invited!')
                    ->rules([
                        'required',
                    ]),
                Text::make('Sender email')
                    ->name('sender_address')
                    ->placeholder('info@example.com')
                    ->rules([
                        'required',
                        'email',
                    ]),
                Text::make('Reply-to email')
                    ->name('reply_to_address')
                    ->placeholder('info@example.com')
                    ->rules([
                        'required',
                        'email',
                    ]),
            ]),
        ];
    })
    ->addActions(function (EventEmail $email) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.email.index', [
                    'event' => $email->event->id,
                ]),
        ];
    })
    ->addPrimaryAction(function (EventEmail $email) {
        return Button::make('Update Email')
            ->method(InertiaMethod::POST())
            ->route('admin.email.update', [
                'event' => $email->event->id,
                'email' => $email->id,
            ]);
    });
