<?php

namespace EventPortal\Tests\Feature\Admin\Permission;

use EventPortal\Domain\Permission\Models\Group as GroupModel;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class PermissionStoreTest extends TestCase
{
    use DatabaseMigrations, SeedRolesAndPermissions;

    /** @test */
    public function can_give_a_role_permissions()
    {
        $group = factory(GroupModel::class)->state('default')->create();
        $role = factory(Role::class)->create([
            'name' => 'role',
            'label' => 'Role',
        ]);
        $permission = factory(Permission::class)->create([
            'name' => 'permission.manage',
            'label' => 'Permission',
            'group_id' => $group->id,
        ]);

        $this->actingAsAdmin()
            ->post(route('admin.permission.update'), [
                [
                    'permissionId' => 'permission.manage',
                    'roleId' => 'role',
                    'selected' => true,
                ],
            ]);

        $this->assertTrue($role->hasPermissionTo('permission.manage'));
        $this->assertDatabaseHas('role_has_permissions', [
            'role_id' => $role->id,
            'permission_id' => $permission->id,
        ]);
    }

    /** @test */
    public function can_revoke_permissions()
    {
        $group = factory(GroupModel::class)->state('default')->create();
        $role = factory(Role::class)->create([
            'name' => 'role',
            'label' => 'Role',
        ]);
        $permission = factory(Permission::class)->create([
            'name' => 'permission.manage',
            'label' => 'Permission',
            'group_id' => $group->id,
        ]);
        $role->givePermissionTo('permission.manage');
        $this->assertTrue($role->hasPermissionTo('permission.manage'));

        $this->actingAsAdmin()
            ->post(route('admin.permission.update'), [
                [
                    'permissionId' => 'permission.manage',
                    'roleId' => 'role',
                    'selected' => false,
                ],
            ]);

        $this->assertFalse($role->fresh()->hasPermissionTo('permission.manage'));
        $this->assertDatabaseMissing('role_has_permissions', [
            'role_id' => $role->id,
            'permission_id' => $permission->id,
        ]);
    }
}
