<?php

namespace EventPortal\Tests\Unit;

use EventPortal\Domain\Component\Value;
use EventPortal\Tests\TestCase;

class ValueTest extends TestCase
{
    /** @test **/
    public function can_get_value_of_string()
    {
        $this->assertEquals('One', Value::get('One'));
    }

    /** @test **/
    public function can_detect_array()
    {
        $array = [
            'label' => 'One',
            'value' => 'one',
        ];

        $this->assertTrue(Value::isArray($array));
    }

    /** @test **/
    public function can_get_value_of_array()
    {
        $array = [
            'label' => 'One',
            'value' => 'one',
        ];

        $this->assertEquals('One', Value::get($array));
    }

    /** @test **/
    public function can_detect_multi_level_array()
    {
        $array = [
            [
                'label' => 'One',
                'value' => 'one',
            ],
            [
                'label' => 'Two',
                'value' => 'two',
            ],
        ];

        $this->assertTrue(Value::isMultiLevelArray($array));
    }

    /** @test **/
    public function can_get_values_of_multi_level_array()
    {
        $array = [
            [
                'label' => 'One',
                'value' => 'one',
            ],
            [
                'label' => 'Two',
                'value' => 'two',
            ],
        ];

        $this->assertEquals('One, Two', Value::get($array));
    }

    /** @test **/
    public function filters_out_false_of_multi_array()
    {
        $array = [
            [
                'label' => 'Burger',
                'value' => false,
            ],
            [
                'label' => 'Chips',
                'value' => true,
            ],
            [
                'label' => 'Milkshake',
                'value' => true,
            ],
        ];

        $this->assertEquals('Chips, Milkshake', Value::get($array));
    }

    /** @test **/
    public function can_turn_boolean_into_string()
    {
        $this->assertEquals('True', Value::get(true));
        $this->assertEquals('False', Value::get(false));
    }

    /** @test **/
    public function can_turn_null_into_string()
    {
        $this->assertEquals('False', Value::get(null, true));
    }

    /** @test **/
    public function can_get_value_of_json()
    {
        $data = [
            'label' => 'Type',
            'value' => 'type',
        ];

        $this->assertEquals('Type', Value::get(json_encode($data)));
    }
}
